**********************
aas-core3.0-python
**********************

.. image:: https://github.com/aas-core-works/aas-core3.0-python/actions/workflows/ci.yml/badge.svg
    :target: https://github.com/aas-core-works/aas-core3.0-python/actions/workflows/ci.yml
    :alt: Continuous integration

.. image:: https://coveralls.io/repos/github/aas-core-works/aas-core3.0-python/badge.svg?branch=main
    :target: https://coveralls.io/github/aas-core-works/aas-core3.0-python?branch=main
    :alt: Test coverage

.. image:: https://badge.fury.io/py/aas-core3.0.svg
    :target: https://badge.fury.io/py/aas-core3.0
    :alt: PyPI - version

.. image:: https://img.shields.io/pypi/pyversions/aas-core3.0.svg
    :alt: PyPI - Python Version

.. image:: https://readthedocs.org/projects/aas-core30-python/badge/?version=latest
    :target: https://aas-core30-python.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation

This is a software development kit (SDK) to manipulate, verify and de/serialize Asset Administration Shells based on the version 3.0 of the meta-model.

The documentation is available on: https://aas-core30-python.readthedocs.io/en/latest/.

The majority of the code has been automatically generated by `aas-core-codegen`_.

If you want to contribute, see our `contributing guide`_.

.. _aas-core-codegen: https://github.com/aas-core-works/aas-core-codegen

.. _contributing guide: https://aas-core30-python.readthedocs.io/en/latest/contributing.html
